Resources — Map of Objects

Skip to main content
`Ctrl`+`K`

# Resources

Additional resources related to the concept of map of elections or other objects.

## Related Papers

List of papers using mapof (from the most recent to the oldest).

- A Map of Diverse Synthetic Stable Matching Instances

- Guide to Numerical Experiments on Elections in Computational Social Choice

- Discovering Consistent Subelections

- Participatory Budgeting: Data, Tools and Analysis

- An Experimental Comparison of Multiwinner Voting Rules on Approval Elections

- Diversity, Agreement, and Polarization in Elections

- Expected Frequency Matrices of Elections: Computation, Geometry, and Preference Learning

- How to Sample Approval Elections?

- Understanding Distance Measures Among Elections

- Putting a Compass on the Map of Elections

- Drawing a Map of Elections in the Space of Statistical Cultures

## Datasets & Examples

In the mapof-data repository you can find the datasets used in the papers above and some examples of how to use them.

## Tutorial

Recently, at AAAI, IJCAI, and AAMAS conferences a tutorial related to conducting experiments with the use of map of elections was held. The slides from these tutorials are available HERE